==> mule-artifact-ast-serialization-1.0.0-20221024-test-sources.jar: org/mule/runtime/ast/api/serialization/ArtifactAstSerializerProviderTestCase.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.api.serialization;

import static org.mule.runtime.ast.AllureConstants.ArtifactAstSerialization.AST_SERIALIZATION;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.instanceOf;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;

import io.qameta.allure.Feature;
import org.junit.Before;
import org.junit.Test;
import org.mule.runtime.ast.internal.serialization.DefaultArtifactAstDeserializer;
import org.mule.runtime.ast.internal.serialization.ArtifactAstSerializerFactory;

@Feature(AST_SERIALIZATION)
public class ArtifactAstSerializerProviderTestCase {

  private ArtifactAstSerializerProvider artifactAstSerializerProvider;
  private ArtifactAstSerializerFactory artifactAstSerializerFactory;

  @Before
  public void setUp() {
    artifactAstSerializerFactory = mock(ArtifactAstSerializerFactory.class);
    artifactAstSerializerProvider = new ArtifactAstSerializerProvider(artifactAstSerializerFactory);
  }

  @Test
  public void testGetSerializerCallsSerializerFactoryGetSerializerWithJSONParam_WhenGettingAJsonSerializer() {
    // Given
    String format = "JSON";

    // When
    artifactAstSerializerProvider.getSerializer(format);

    // Then
    verify(artifactAstSerializerFactory, times(1)).getSerializer(format);
  }

  @Test
  public void testGetSerializerCallsSerializerFactoryGetSerializerWithKlingonParam_WhenGettingAKlingonSerializer() {
    // Given
    String format = "Klingon";

    // When
    artifactAstSerializerProvider.getSerializer(format);

    // Then
    verify(artifactAstSerializerFactory, times(1)).getSerializer(format);
  }

  @Test
  public void testGetDeserializerReturnsDefaultArtifactAstDeserializerInstance_WhenGettingADeserializer() {
    // Given

    // When
    ArtifactAstDeserializer deserializer = artifactAstSerializerProvider.getDeserializer();

    // Then
    assertThat(deserializer, instanceOf(DefaultArtifactAstDeserializer.class));
  }

}

==> mule-artifact-ast-serialization-1.1.0-rc3-test-sources.jar: org/mule/runtime/ast/api/serialization/ArtifactAstSerializerProviderTestCase.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.api.serialization;

import static org.mule.runtime.ast.AllureConstants.ArtifactAstSerialization.AST_SERIALIZATION;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.instanceOf;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;

import io.qameta.allure.Feature;
import org.junit.Before;
import org.junit.Test;
import org.mule.runtime.ast.internal.serialization.DefaultArtifactAstDeserializer;
import org.mule.runtime.ast.internal.serialization.ArtifactAstSerializerFactory;

@Feature(AST_SERIALIZATION)
public class ArtifactAstSerializerProviderTestCase {

  private ArtifactAstSerializerProvider artifactAstSerializerProvider;
  private ArtifactAstSerializerFactory artifactAstSerializerFactory;

  @Before
  public void setUp() {
    artifactAstSerializerFactory = mock(ArtifactAstSerializerFactory.class);
    artifactAstSerializerProvider = new ArtifactAstSerializerProvider(artifactAstSerializerFactory);
  }

  @Test
  public void testGetSerializerCallsSerializerFactoryGetSerializerWithJSONParam_WhenGettingAJsonSerializer() {
    // Given
    String format = "JSON";

    // When
    artifactAstSerializerProvider.getSerializer(format, "1.0");

    // Then
    verify(artifactAstSerializerFactory, times(1)).getSerializer(format, "1.0");
  }

  @Test
  public void testGetSerializerCallsSerializerFactoryGetSerializerWithKlingonParam_WhenGettingAKlingonSerializer() {
    // Given
    String format = "Klingon";

    // When
    artifactAstSerializerProvider.getSerializer(format, "1.0");

    // Then
    verify(artifactAstSerializerFactory, times(1)).getSerializer(format, "1.0");
  }

  @Test
  public void testGetDeserializerReturnsDefaultArtifactAstDeserializerInstance_WhenGettingADeserializer() {
    // Given

    // When
    ArtifactAstDeserializer deserializer = artifactAstSerializerProvider.getDeserializer();

    // Then
    assertThat(deserializer, instanceOf(DefaultArtifactAstDeserializer.class));
  }

}
